@@ -306,13 +306,6 @@ if (current_page == 'index.html') {
     }
 }
 
-
-// Introduction/Features = Animation
-if (current_page == 'introduction.html' || current_page == 'features.html') {
-    new WOW().init();
-}
-
-
 // Getting Started Only - Index Pane for Selecting Topics
 if (current_page == 'gettingstarted.html') {
 
@@ -443,7 +436,12 @@ if (current_page == 'gettingstarted.html') {
         if (!$('#index-menu').is(':visible')) {
             indexOpen();
         } else {
-            smoothPageFade('index.html');
+            if ($('#first-run').is(':visible')) {
+                smoothPageFade('default.html');
+            }
+            else {
+                smoothPageFade('index.html');
+            }
         }
     }
 }
@@ -468,4 +466,11 @@ function sortList() {
         return titleOne.localeCompare(titleTwo);
     }));
 }
-//}
\ No newline at end of file
+//}
+
+function injectTitle() {
+    var title = $("#title-inject").text();
+    document.title = "title?" + title;
+}
+
+injectTitle();
